pub fn required_dependencies(code: &str) -> Vec<Dependency>Expand description
Inspect generated code and return the external crates it references, in a
stable order (shared model crates, then server crates, then client crates).
pub fn required_dependencies(code: &str) -> Vec<Dependency>Inspect generated code and return the external crates it references, in a
stable order (shared model crates, then server crates, then client crates).