pub fn apply(doc: &mut OpenAPI, opts: &OutputOptions)Expand description
Apply the configured operation and schema filters to doc in place.
pub fn apply(doc: &mut OpenAPI, opts: &OutputOptions)Apply the configured operation and schema filters to doc in place.