Derivation of the Rust names of the artifacts generated for an operation. Deriving the Rust names of the artifacts generated for one OpenAPI operation.
Centralised so the server emitter and (later) the client emitter derive the same names from the same operation identifier, and cannot drift apart.
Functions
- axum_
handler_ name - cookies_
struct_ name - The generated cookie-struct name for an operation (
<Op>Cookies). - headers_
struct_ name - multipart_
struct_ name - The generated multipart-extractor struct name for an operation
(
<Op>Multipart). - operation_
method_ name - query_
struct_ name - request_
body_ enum_ name - The generated dispatch-enum name for an operation whose request body offers
several content types (
<Op>RequestBody). - response_
body_ enum_ name - The generated body-enum name for a response variant that offers several
content types (
<Response><Variant>Body). - response_
enum_ name - The generated response-enum name for an operation,
<Op><Suffix>(the suffix defaults toResponse. Override it viaresponse-type-suffixto resolve a clash with a component schema of the same name).